<!DOCTYPE html>
<html>
  <head>
    <meta name="viewport" content="initial-scale=1.0, user-scalable=no">
    <meta charset="utf-8">
    <title>County Overlay</title>
    <link rel="stylesheet" href="CQX_StyleSheet-new.css" type="text/css" />

    <style>
      html, body, #map-canvas {
        height: 100%;
        margin: 0px;
        padding: 0px
      }
      html, body, #countySelection{width: 100%; height: 100%}
    </style>


    <script src="https://maps.googleapis.com/maps/api/js?v=3.exp"></script>

    <script language="javascript" type="text/javascript">

    var map;
    var infoWindow;
    var theCountyMarkers = new Array();
    var theCountyValues = new Array();
    var cqxUrl = "http://www.no5w.com";


    var stateFullName = "South Carolina";
    var qsoPartyUrl = "http://scqso.com/rules/";
    var overlayUrl = "http://www.no5w.com/OverlaySouthCarolinaRev3.kml";

    /*-----------------------------------------------------------------------------------------------------
     PromoControl: constructor for the QSO Party promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function PromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access QSO Party home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '24px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String(stateFullName) + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(qsoPartyUrl));
      });
    }//PromoControl constructor

    /*-----------------------------------------------------------------------------------------------------
     CQXPromoControl: constructor for the CQ/X promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function CQXPromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access CQ/X home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '12px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String("CQ/X de NO5W") + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(cqxUrl));
      });
    }//CQXPromoControl constructor

/*-----------------------------------------------------------------------------------------------------
 addMarker: function for adding a county marker
-----------------------------------------------------------------------------------------------------*/
function addMarker(lat, lon, desc, aval) {
  var markerLatLng = new google.maps.LatLng(lat, lon);

  var markerOptions = {
    flat: true,
    map: map,
    optimized: false,
    position: markerLatLng,
    visible: true,
    title: desc
    };
  var marker = new google.maps.Marker(markerOptions);
  theCountyMarkers.push(marker);
  theCountyValues.push(aval);

  }//addMarker

/*-----------------------------------------------------------------------------------------------------
 removeMarkers: function for removing all of the current markers
 -----------------------------------------------------------------------------------------------------*/
function removeMarkers() {
  for(var i=0;i<theCountyMarkers.length;i++) theCountyMarkers[i].setMap(null);
  }//removeMarkers     

/*-----------------------------------------------------------------------------------------------------
 populateCountySelection: function for building the county selection
 -----------------------------------------------------------------------------------------------------*/
function populateCountySelection() {
  var countySelection = document.getElementById("countySelection");
          
  countySelection.options.length = 0;
  theCountyMarkers.length = 0;
  theCountyValues.length = 0;

  countySelection.options[0] = new Option("Abbeville", "abbe");
  countySelection.options[1] = new Option("Aiken", "aike");
  countySelection.options[2] = new Option("Allendale", "alle");
  countySelection.options[3] = new Option("Anderson", "ande");
  countySelection.options[4] = new Option("Bamberg", "bamb");
  countySelection.options[5] = new Option("Barnwell", "barn");
  countySelection.options[6] = new Option("Beaufort", "beau");
  countySelection.options[7] = new Option("Berkeley", "berk");
  countySelection.options[8] = new Option("Calhoun", "chou");
  countySelection.options[9] = new Option("Charleston", "char");
  countySelection.options[10] = new Option("Cherokee", "ckee");
  countySelection.options[11] = new Option("Chester", "ches");
  countySelection.options[12] = new Option("Chesterfield", "chfd");
  countySelection.options[13] = new Option("Clarendon", "clrn");
  countySelection.options[14] = new Option("Colleton", "coll");
  countySelection.options[15] = new Option("Darlington", "darl");
  countySelection.options[16] = new Option("Dillon", "dill");
  countySelection.options[17] = new Option("Dorchester", "dorc");
  countySelection.options[18] = new Option("Edgefield", "edge");
  countySelection.options[19] = new Option("Fairfield", "fair");
  countySelection.options[20] = new Option("Florence", "flor");
  countySelection.options[21] = new Option("Georgetown", "geor");
  countySelection.options[22] = new Option("Greenville", "gvil");
  countySelection.options[23] = new Option("Greenwood", "grwd");
  countySelection.options[24] = new Option("Hampton", "hamp");
  countySelection.options[25] = new Option("Horry", "horr");
  countySelection.options[26] = new Option("Jasper", "jasp");
  countySelection.options[27] = new Option("Kershaw", "kers");
  countySelection.options[28] = new Option("Lancaster", "lncs");
  countySelection.options[29] = new Option("Laurens", "laur");
  countySelection.options[30] = new Option("Lee", "lee");
  countySelection.options[31] = new Option("Lexington", "lexi");
  countySelection.options[32] = new Option("Marion", "mari");
  countySelection.options[33] = new Option("Marlboro", "marl");
  countySelection.options[34] = new Option("McCormick", "mcor");
  countySelection.options[35] = new Option("Newberry", "newb");
  countySelection.options[36] = new Option("Oconee", "ocon");
  countySelection.options[37] = new Option("Orangeburg", "orng");
  countySelection.options[38] = new Option("Pickens", "pick");
  countySelection.options[39] = new Option("Richland", "rich");
  countySelection.options[40] = new Option("Saluda", "salu");
  countySelection.options[41] = new Option("Spartanburg", "spar");
  countySelection.options[42] = new Option("Sumter", "sumt");
  countySelection.options[43] = new Option("Union", "unio");
  countySelection.options[44] = new Option("Williamsburg", "will");
  countySelection.options[45] = new Option("York", "york");
  addMarker(34.24900000, -82.49050000, "Abbeville", "abbe");
  addMarker(33.53770000, -81.59990000, "Aiken", "aike");
  addMarker(32.95160000, -81.34860000, "Allendale", "alle");
  addMarker(34.51410000, -82.65310000, "Anderson", "ande");
  addMarker(33.23320000, -81.01290000, "Bamberg", "bamb");
  addMarker(33.29170000, -81.48280000, "Barnwell", "barn");
  addMarker(32.39060000, -80.72280000, "Beaufort", "beau");
  addMarker(33.16420000, -79.90420000, "Berkeley", "berk");
  addMarker(33.67300000, -80.77840000, "Calhoun", "chou");
  addMarker(32.85440000, -79.86140000, "Charleston", "char");
  addMarker(35.01170000, -81.62060000, "Cherokee", "ckee");
  addMarker(34.68280000, -81.17390000, "Chester", "ches");
  addMarker(34.59180000, -80.17060000, "Chesterfield", "chfd");
  addMarker(33.68840000, -80.20800000, "Clarendon", "clrn");
  addMarker(32.82590000, -80.66610000, "Colleton", "coll");
  addMarker(34.31050000, -79.97270000, "Darlington", "darl");
  addMarker(34.42560000, -79.35230000, "Dillon", "dill");
  addMarker(33.07560000, -80.43470000, "Dorchester", "dorc");
  addMarker(33.75450000, -81.91730000, "Edgefield", "edge");
  addMarker(34.37330000, -81.09870000, "Fairfield", "fair");
  addMarker(34.04160000, -79.69350000, "Florence", "flor");
  addMarker(33.44490000, -79.34150000, "Georgetown", "geor");
  addMarker(34.84970000, -82.45560000, "Greenville", "gvil");
  addMarker(34.18140000, -82.10130000, "Greenwood", "grwd");
  addMarker(32.79150000, -81.12690000, "Hampton", "hamp");
  addMarker(33.93550000, -78.94010000, "Horry", "horr");
  addMarker(32.39380000, -81.04940000, "Jasper", "jasp");
  addMarker(34.34190000, -80.58220000, "Kershaw", "kers");
  addMarker(34.76730000, -80.65890000, "Lancaster", "lncs");
  addMarker(34.49430000, -81.97910000, "Laurens", "laur");
  addMarker(34.16000000, -80.24100000, "Lee", "lee");
  addMarker(33.92520000, -81.24830000, "Lexington", "lexi");
  addMarker(33.99740000, -79.34920000, "Marion", "mari");
  addMarker(34.55230000, -79.69230000, "Marlboro", "marl");
  addMarker(33.83560000, -82.31990000, "McCormick", "mcor");
  addMarker(34.30220000, -81.63100000, "Newberry", "newb");
  addMarker(34.76410000, -83.08800000, "Oconee", "ocon");
  addMarker(33.44200000, -80.79750000, "Orangeburg", "orng");
  addMarker(34.84730000, -82.71010000, "Pickens", "pick");
  addMarker(34.00600000, -80.97080000, "Richland", "rich");
  addMarker(34.00090000, -81.74110000, "Saluda", "salu");
  addMarker(34.88820000, -81.96910000, "Spartanburg", "spar");
  addMarker(33.90630000, -80.27010000, "Sumter", "sumt");
  addMarker(34.67890000, -81.63490000, "Union", "unio");
  addMarker(33.59840000, -79.70940000, "Williamsburg", "will");
  addMarker(34.99260000, -81.17870000, "York", "york");

  countySelection.selectedIndex = 0;
  }

//----------------------------------------------------------------------------------------------------

function initialize() {

  populateCountySelection();

  var mapOptions = {
    zoom: 11
    };

  map = new google.maps.Map(document.getElementById('map-canvas'), mapOptions);

  var stateLayer = new google.maps.KmlLayer({url: overlayUrl, suppressInfoWindows: true});
  stateLayer.setMap(map);

  // Add a listener for the click event.
  google.maps.event.addListener(stateLayer, 'click', showLatLon);

  infoWindow = new google.maps.InfoWindow();

  var promoControlDiv = document.createElement('div');
  var promoControl = new PromoControl(promoControlDiv, map);

  promoControlDiv.index = 1;
  map.controls[google.maps.ControlPosition.TOP_CENTER].push(promoControlDiv);

  var promoCQXControlDiv = document.createElement('div');
  var promoCQXControl = new CQXPromoControl(promoCQXControlDiv, map);

  promoCQXControlDiv.index = 2;
  map.controls[google.maps.ControlPosition.TOP_RIGHT].push(promoCQXControlDiv);

  }

/*-----------------------------------------------------------------------------------------------------
 changeCounty: function processing a county change from the countySelection 
 -----------------------------------------------------------------------------------------------------*/
function changeCounty() {
  removeMarkers();
  var acounty = encodeURIComponent(document.getElementById("countySelection").value);
  var iMark = -1;
  for(i=0;i<theCountyValues.length;i++) {
    if(theCountyValues[i] != acounty) continue;
    iMark = i;
    break;
    }
  if(iMark < 0) return;
  map.setCenter(theCountyMarkers[iMark].getPosition());
  theCountyMarkers[iMark].setMap(map);
  }//function changeCounty

function catchEvent(eventObj, event, eventHandler) {
  if(eventObj.addEventListener) {
    eventObj.addEventListener(event, eventHandler, false);
    }
  else if(eventObj.attachEvent) {
    event = "on" + event;
    eventObj.attachEvent(event, eventHandler);
    }
  }//catchEvent

/*-----------------------------------------------------------------------------------------------------
 set up event handlers when the window loads 
 -----------------------------------------------------------------------------------------------------*/
catchEvent(window, "load", function() {
  document.getElementById("countySelection").onchange=changeCounty;
  });

function showLatLon(event) {

  var nameStr = event.featureData.name; //FullName=Abbrev Num
  var arrayOne = nameStr.split("=");
  var arrayTwo = arrayOne[1].split(" ");

  var contentString = '<b>Clicked on Location</b>' + '<br>' +
                    '<b>LatLon: </b>' + event.latLng.lat() + ',' + event.latLng.lng() + '<br>' +
                    '<b>In County: </b>' + arrayOne[0] + '(' + arrayTwo[0] + ')';

  // Replace the info window's content and position.
  infoWindow.setContent(contentString);
  infoWindow.setPosition(event.latLng);

  infoWindow.open(map);
  }

google.maps.event.addDomListener(window, 'load', initialize);


    </script>
  </head>

  <body>

    <table style="width: 1000px;">
      <tbody>
        <tr style="vertical-align: top;">

          <td>
          <form>
            <div class="elem" style = "width: 120px; height: 700px; margin: 0; padding: 0; overflow:auto;">
              <select id="countySelection" name="county" size='43'>
                <option> </option>
              </select>
            </div>
          </form>
          </td>

          <td>
            <div id="map-canvas" style="width: 880px; height: 700px;"></div>
          </td>
        </tr>
      </tbody>
    </table>

  </body>


</html>

